@@ -13,7 +13,7 @@ such as the coordinates and visible status(optional).
 
 """
 
-from typing import Dict, List, Optional, Sequence, Type, TypeVar
+from typing import Dict, Iterable, List, Optional, Type, TypeVar
 
 from ..utility import common_loads
 from .polygon import PointList2D
@@ -33,13 +33,6 @@ class Keypoint2D(Vector2D):
         y: The y coordinate of the 2D keypoint.
         v: The visible status(optional) of the 2D keypoint.
 
-            .. code:: python
-
-                keypoint2d = Keypoint2D(x=1.0, y=2.0)
-                keypoint2d = Keypoint2D(x=1.0, y=2.0, v=0)
-                keypoint2d = Keypoint2D(x=1.0, y=2.0, v=1)
-                keypoint2d = Keypoint2D(x=1.0, y=2.0, v=2)
-
             Visible status can be "BINARY" or "TERNARY":
 
             +---------------+---------+-----------+-----------+
@@ -50,6 +43,16 @@ class Keypoint2D(Vector2D):
             | TERNARY       | visible | occluded  | invisible |
             +---------------+---------+-----------+-----------+
 
+    Examples:
+        *Initialization Method 1:* Init from coordinates of x, y.
+
+        >>> Keypoint2D(1.0, 2.0)
+        Keypoint2D(1.0, 2.0)
+
+        *Initialization Method 2:* Init from coordinates and visible status.
+
+        >>> Keypoint2D(1.0, 2.0, 0)
+        Keypoint2D(1.0, 2.0, 0)
 
     """
 
@@ -63,7 +66,7 @@ class Keypoint2D(Vector2D):
         result._data = tuple(-coordinate for coordinate in self._data[: self._DIMENSION])
         return result
 
-    def __add__(self, other: Sequence[float]) -> Vector2D:  # type: ignore[override]
+    def __add__(self, other: Iterable[float]) -> Vector2D:  # type: ignore[override]
         # Result of adding Keypoint2D with another sequence should be a Vector2D.
         # Add function of Vector2D should also add support for adding with a Keypoint2D.
         # Will be implemented in the future.
@@ -75,17 +78,16 @@ class Keypoint2D(Vector2D):
 
         Arguments:
             contents: A dict containing coordinates and visible status(optional)
-                of a 2D keypoint::
-
-                    {
-                        "x": ...
-                        "y": ...
-                        "v": ...
-                    }
+                of a 2D keypoint.
 
         Returns:
             The loaded :class:`Keypoint2D` object.
 
+        Examples:
+            >>> contents = {"x":1.0,"y":2.0,"v":1}
+            >>> Keypoint2D.loads(contents)
+            Keypoint2D(1.0, 2.0, 1)
+
         """
         return cls(**contents)
 
@@ -96,6 +98,11 @@ class Keypoint2D(Vector2D):
         Returns:
             Visible status of the 2D keypoint.
 
+        Examples:
+            >>> keypoint = Keypoint2D(3.0, 2.0, 1)
+            >>> keypoint.v
+            1
+
         """
         if len(self._data) != self._DIMENSION:
             return self._data[2]  # type: ignore[return-value]
@@ -107,6 +114,11 @@ class Keypoint2D(Vector2D):
         Returns:
             A dict containing coordinates and visible status(optional) of the 2D keypoint.
 
+        Examples:
+            >>> keypoint = Keypoint2D(1.0, 2.0, 1)
+            >>> keypoint.dumps()
+            {'x': 1.0, 'y': 2.0, 'v': 1}
+
         """
         contents = {"x": self._data[0], "y": self._data[1]}
         if len(self._data) != self._DIMENSION:
@@ -120,6 +132,13 @@ class Keypoints2D(PointList2D[Keypoint2D]):
     :class:`Keypoints2D` contains a list of 2D keypoint and is based on
     :class:`~tensorbay.geometry.polygon.PointList2D`.
 
+    Examples:
+        >>> Keypoints2D([[1, 2], [2, 3]])
+        Keypoints2D [
+          Keypoint2D(1, 2),
+          Keypoint2D(2, 3)
+        ]
+
     """
 
     _P = TypeVar("_P", bound="Keypoints2D")
@@ -133,17 +152,16 @@ class Keypoints2D(PointList2D[Keypoint2D]):
         Arguments:
             contents: A list of dictionaries containing 2D keypoint::
 
-                [
-                    {
-                        "x": ...
-                        "y": ...
-                        "v": ...           --- optional
-                    },
-                    ...
-                ]
-
         Returns:
             The loaded :class:`Keypoints2D` object.
 
+        Examples:
+            >>> contents = [{"x": 1.0, "y": 1.0, "v": 1}, {"x": 2.0, "y": 2.0, "v": 2}]
+            >>> Keypoints2D.loads(contents)
+            Keypoints2D [
+              Keypoint2D(1.0, 1.0, 1),
+              Keypoint2D(2.0, 2.0, 2)
+            ]
+
         """
         return common_loads(cls, contents)
