@@ -14,11 +14,11 @@ and :attr:`Transform3D.rotation` is stored as `numpy quaternion`_.
 """
 
 import warnings
-from typing import Dict, Iterable, Sequence, Type, TypeVar, Union, overload
+from typing import Dict, Iterable, Optional, Type, TypeVar, Union, overload
 
 import numpy as np
 
-from ..utility import ReprMixin, ReprType, common_loads
+from ..utility import MatrixType, ReprMixin, ReprType, common_loads
 from .vector import Vector3D
 
 with warnings.catch_warnings():
@@ -34,43 +34,62 @@ class Transform3D(ReprMixin):
     :class:`Transform3D` contains rotation and translation of the 3D transform.
 
     Arguments:
-        transform: A :class:`Transform3D` or a 4x4 or 3x4 transform matrix.
         translation: Translation in a sequence of [x, y, z].
         rotation: Rotation in a sequence of [w, x, y, z] or numpy quaternion.
+        matrix: A 4x4 or 3x4 transform matrix.
 
     Raises:
         ValueError: If the shape of the input matrix is not correct.
 
+    Examples:
+        *Initialization Method 1:* Init from translation and rotation.
+
+        >>> Transform3D([1, 1, 1], [1, 0, 0, 0])
+        Transform3D(
+          (translation): Vector3D(1, 1, 1),
+          (rotation): quaternion(1, 0, 0, 0)
+        )
+
+        *Initialization Method 2:* Init from transform matrix in sequence.
+
+        >>> Transform3D(matrix=[[1, 0, 0, 1], [0, 1, 0, 1], [0, 0, 1, 1]])
+        Transform3D(
+          (translation): Vector3D(1, 1, 1),
+          (rotation): quaternion(1, -0, -0, -0)
+        )
+
+        *Initialization Method 3:* Init from transform matrix in numpy array.
+
+        >>> import numpy as np
+        >>> Transform3D(matrix=np.array([[1, 0, 0, 1], [0, 1, 0, 1], [0, 0, 1, 1]]))
+        Transform3D(
+          (translation): Vector3D(1, 1, 1),
+          (rotation): quaternion(1, -0, -0, -0)
+        )
+
     """
 
     _repr_type = ReprType.INSTANCE
     _repr_attrs = ("translation", "rotation")
 
-    MatrixType = Union[None, Sequence[Sequence[float]], np.ndarray]
-    TransformType = Union[None, "Transform3D", Sequence[Sequence[float]], np.ndarray]
     RotationType = Union[Iterable[float], quaternion]
 
     def __init__(
         self,
-        transform: TransformType = None,
-        *,
         translation: Iterable[float] = (0, 0, 0),
         rotation: RotationType = (1, 0, 0, 0),
+        *,
+        matrix: Optional[MatrixType] = None,
     ) -> None:
-        if transform is not None:
-            if isinstance(transform, Transform3D):
-                self._translation = transform.translation
-                self._rotation = transform.rotation
+        if matrix is not None:
+            try:
+                self._translation = Vector3D(matrix[0][3], matrix[1][3], matrix[2][3])
+                self._rotation = from_rotation_matrix(matrix)
                 return
-
-            if isinstance(transform, Sequence):  # pylint: disable=W1116
-                transform = np.array(transform)
-            if transform.shape != (3, 4) and transform.shape != (4, 4):
-                raise ValueError("The shape of input transform matrix must be 3x4 or 4x4.")
-
-            self._translation = Vector3D(transform[0, 3], transform[1, 3], transform[2, 3])
-            self._rotation = from_rotation_matrix(transform)
-            return
+            except (IndexError, TypeError) as error:
+                raise ValueError(
+                    "The shape of input transform matrix must be 3x4 or 4x4."
+                ) from error
 
         self._translation = Vector3D(*translation)
         if isinstance(rotation, quaternion):
@@ -89,30 +108,37 @@ class Transform3D(ReprMixin):
         ...
 
     @overload
-    def __mul__(self: _T, other: Sequence[float]) -> Vector3D:
+    def __mul__(self: _T, other: Iterable[float]) -> Vector3D:
         ...
 
-    def __mul__(self: _T, other: Union[_T, Sequence[float]]) -> Union[_T, Vector3D]:
-        if isinstance(other, Sequence):  # pylint: disable=W1116
-            result: Vector3D = self._translation + rotate_vectors(self._rotation, other)
-            return result
+    def __mul__(self: _T, other: Union[_T, Iterable[float]]) -> Union[_T, Vector3D]:
+        try:
+            if isinstance(other, Transform3D):
+                return self._create(
+                    self._mul_vector(other.translation), self._rotation * other.rotation
+                )
 
-        # mypy does not recognize quaternion type, and will infer it as Any.
-        # This typing problem to be resolved.
-        if isinstance(other, quaternion):
-            return self._create(self._translation, self._rotation * other)
+            # mypy does not recognize quaternion type, and will infer it as Any.
+            # This typing problem to be resolved.
+            if isinstance(other, quaternion):
+                return self._create(self._translation, self._rotation * other)
 
-        if isinstance(other, Transform3D):
-            return self._create(self * other.translation, self._rotation * other.rotation)
+            return self._mul_vector(other)  # type: ignore[arg-type]
 
-        return NotImplemented  # type: ignore[unreachable]
+        except (TypeError, ValueError):
+            pass
+
+        return NotImplemented
 
     def __rmul__(self: _T, other: quaternion) -> _T:
-        if isinstance(other, quaternion):
-            return self._create(
-                Vector3D(*rotate_vectors(other, self._translation)),
-                other * self._rotation,
-            )
+        try:
+            if isinstance(other, quaternion):
+                return self._create(
+                    Vector3D(*rotate_vectors(other, self._translation)),
+                    other * self._rotation,
+                )
+        except ValueError:
+            pass
 
         return NotImplemented
 
@@ -123,6 +149,11 @@ class Transform3D(ReprMixin):
         transform._rotation = rotation  # pylint: disable=protected-access
         return transform
 
+    def _mul_vector(self, other: Iterable[float]) -> Vector3D:
+        # Multiplication with point list is not supported currently.
+        # __radd__ is used to ensure the shape of the input object.
+        return self._translation.__radd__(rotate_vectors(self._rotation, other))
+
     def _loads(self, contents: Dict[str, Dict[str, float]]) -> None:
         self._translation = Vector3D.loads(contents["translation"])
         rotation_contents = contents["rotation"]
@@ -138,25 +169,22 @@ class Transform3D(ReprMixin):
         """Load a :class:`Transform3D` from a dict containing rotation and translation.
 
         Arguments:
-            contents: A dict containing rotation and translation of a 3D transform::
-
-                {
-                    "translation": {
-                        "x": ...
-                        "y": ...
-                        "z": ...
-                    },
-                    "rotation": {
-                        "w": ...
-                        "x": ...
-                        "y": ...
-                        "z": ...
-                    }
-                }
+            contents: A dict containing rotation and translation of a 3D transform.
 
         Returns:
             The loaded :class:`Transform3D` object.
 
+        Example:
+            >>> contents = {
+            ...     "translation": {"x": 1.0, "y": 2.0, "z": 3.0},
+            ...     "rotation": {"w": 1.0, "x": 0.0, "y": 0.0, "z": 0.0},
+            ... }
+            >>> Transform3D.loads(contents)
+            Transform3D(
+              (translation): Vector3D(1.0, 2.0, 3.0),
+              (rotation): quaternion(1, 0, 0, 0)
+            )
+
         """
         return common_loads(cls, contents)
 
@@ -167,6 +195,11 @@ class Transform3D(ReprMixin):
         Returns:
             Translation in :class:`~tensorbay.geometry.vector.Vector3D`.
 
+        Examples:
+            >>> transform = Transform3D([[1, 0, 0, 1], [0, 1, 0, 1], [0, 0, 1, 1]])
+            >>> transform.translation
+            Vector3D(1, 1, 1)
+
         """
         return self._translation
 
@@ -177,6 +210,11 @@ class Transform3D(ReprMixin):
         Returns:
             Rotation in numpy quaternion.
 
+        Examples:
+            >>> transform = Transform3D([[1, 0, 0, 1], [0, 1, 0, 1], [0, 0, 1, 1]])
+            >>> transform.rotation
+            quaternion(1, -0, -0, -0)
+
         """
         return self._rotation
 
@@ -185,7 +223,15 @@ class Transform3D(ReprMixin):
 
         Returns:
             A dict containing rotation and translation information
-                of the :class:`Transform3D`.
+            of the :class:`Transform3D`.
+
+        Examples:
+            >>> transform = Transform3D([[1, 0, 0, 1], [0, 1, 0, 1], [0, 0, 1, 1]])
+            >>> transform.dumps()
+            {
+                'translation': {'x': 1, 'y': 1, 'z': 1},
+                'rotation': {'w': 1.0, 'x': -0.0, 'y': -0.0, 'z': -0.0},
+            }
 
         """
         return {
@@ -205,9 +251,15 @@ class Transform3D(ReprMixin):
             x: The x coordinate of the translation.
             y: The y coordinate of the translation.
             z: The z coordinate of the translation.
-                .. code:: python
 
-                    transform.set_translation(x=1, y=2, z=3)
+        Examples:
+            >>> transform = Transform3D([1, 1, 1], [1, 0, 0, 0])
+            >>> transform.set_translation(3, 4, 5)
+            >>> transform
+            Transform3D(
+              (translation): Vector3D(3, 4, 5),
+              (rotation): quaternion(1, 0, 0, 0)
+            )
 
         """
         self._translation = Vector3D(x, y, z)
@@ -218,6 +270,15 @@ class Transform3D(ReprMixin):
         Arguments:
             rotation: Rotation in a sequence of [w, x, y, z] or numpy quaternion.
 
+        Examples:
+            >>> transform = Transform3D([1, 1, 1], [1, 0, 0, 0])
+            >>> transform.set_rotation([0, 1, 0, 0])
+            >>> transform
+            Transform3D(
+              (translation): Vector3D(1, 1, 1),
+              (rotation): quaternion(0, 1, 0, 0)
+            )
+
         """
         if isinstance(rotation, quaternion):
             self._rotation = quaternion(rotation)
@@ -230,6 +291,14 @@ class Transform3D(ReprMixin):
         Returns:
             A 4x4 numpy array represents the transform matrix.
 
+        Examples:
+            >>> transform = Transform3D([1, 2, 3], [0, 1, 0, 0])
+            >>> transform.as_matrix()
+            array([[ 1.,  0.,  0.,  1.],
+                   [ 0., -1.,  0.,  2.],
+                   [ 0.,  0., -1.,  3.],
+                   [ 0.,  0.,  0.,  1.]])
+
         """
         matrix: np.ndarray = np.eye(4)
         matrix[:3, 3] = self._translation
@@ -242,6 +311,14 @@ class Transform3D(ReprMixin):
         Returns:
             A :class:`Transform3D` object representing the inverse of this :class:`Transform3D`.
 
+        Examples:
+            >>> transform = Transform3D([1, 2, 3], [0, 1, 0, 0])
+            >>> transform.inverse()
+            Transform3D(
+              (translation): Vector3D(-1.0, 2.0, 3.0),
+              (rotation): quaternion(0, -1, -0, -0)
+            )
+
         """
         rotation = self._rotation.inverse()
         translation = Vector3D(*rotate_vectors(rotation, -self._translation))
