@@ -8,12 +8,13 @@
 import pytest
 import ulid
 
+from tensorbay import __version__
 from tensorbay.client.exceptions import GASResponseError
 from tensorbay.client.gas import GAS
 from tensorbay.dataset.data import Data, Label
 from tensorbay.dataset.frame import Frame
 from tensorbay.label.catalog import Catalog
-from tensorbay.sensor.sensor import Sensor
+from tensorbay.sensor.sensor import Sensor, Sensors
 
 from .utility import get_random_dataset_name
 
@@ -227,6 +228,7 @@ class TestSegmentClient:
 
         gas_client.delete_dataset(dataset_name)
 
+    @pytest.mark.xfail(__version__ < "1.5.0", reason="not supported at least until v1.5.0")
     def test_upload_label(self, accesskey, url, tmp_path):
         gas_client = GAS(access_key=accesskey, url=url)
         dataset_name = get_random_dataset_name()
@@ -393,12 +395,11 @@ class TestSegmentClient:
 
         segment_client.upload_sensor(Sensor.loads(LIDAR_DATA))
 
-        sensors = list(segment_client.list_sensors())
-        assert sensors
-        # todo: match the input and output sensors
+        sensors = segment_client.get_sensors()
+        assert sensors == Sensors.loads([LIDAR_DATA])
 
         segment_client.delete_sensor(LIDAR_DATA["name"])
-        sensors = list(segment_client.list_sensors())
+        sensors = segment_client.get_sensors()
         assert len(sensors) == 0
 
         gas_client.delete_dataset(dataset_name)
@@ -502,7 +503,7 @@ class TestSegmentClient:
 
         # Set frame id in frame
         for i in range(5, 10):
-            frame = Frame(frame_id=str(ulid.from_timestamp(i)))
+            frame = Frame(frame_id=ulid.from_timestamp(i))
             local_path = path / f"goodbye{i}.txt"
             local_path.write_text("CONTENT")
             data = Data(local_path=str(local_path))
@@ -511,7 +512,7 @@ class TestSegmentClient:
 
         # Both setting frame id in frame and set timestamp(order) when uploading are not allowed
         i = 10
-        frame = Frame(frame_id=str(ulid.from_timestamp(i)))
+        frame = Frame(frame_id=ulid.from_timestamp(i))
         local_path = path / f"goodbye{i}.txt"
         local_path.write_text("CONTENT")
         data = Data(local_path=str(local_path))
